"{ Encoding: utf8 }"

"{ Package: 'stx:goodies/regression' }"

"{ NameSpace: Smalltalk }"

LibraryDefinition subclass:#stx_goodies_regression
	instanceVariableNames:''
	classVariableNames:''
	poolDictionaries:''
	category:'* Projects & Packages *'
!

!stx_goodies_regression class methodsFor:'documentation'!

documentation
"
    Package documentation:

    stx regression tests (unit tests)
"
! !

!stx_goodies_regression class methodsFor:'accessing - tests'!

testCaseNamesWithoutNamespace
    ^#(
     "/ 'SunitXMLOutputTest'
    'ProjectDefinitionTests'
    'CoverageInstrumentationTest'
    'AssociationTests'
    'BinaryIOTests'
    'BinaryTreeTester'
    "/ 'BlockTest'
    'CharacterTests'
    'CollectionTests'
    'CompilerTest'
    'ComplexTest'
    "/ 'STCCompilerTests'
    "/ 'DebuggerTest'
    "/ 'DeepCopyTests'
    'DelayTest'
    'DictionaryTest'
    'EnumerationTests'
    'ExceptionTest'
    "/ 'ExternalInterfaceTests'
    "/ 'FileOpenTest'
    'FileStreamTest'
    'FloatTest'
    'FractionTest'
    "/ 'GCTest'
    "/ 'GraphicDrawingTest'
    "/ 'HTMLParserTests'
    "/ 'ImageReaderTest'
    'IntegerTest'
    'JavaScriptTests'
    "/ 'MeasurementValueTests'
    "/ 'MemoryTest'
    'NumberTest'
    'ParserTest'
    'ScaledDecimalTest'
    "/ 'SemaphoreTest'
    "/ 'SharedQueueTest'
    'SmallIntegerTest'
    "/ 'SortTests'
    'StringTests'
    'StreamTests'
    'TimeAndDateTest'
    'TimeDurationTest'
    "/ 'URLTest'
    "/ 'XMLCoderTests'
    "/ 'ZipArchiveTests'
    'ClassBuilderTests'
    "/ 'CompilerTests2'
    'ChangeSetTests'
    'FilenameTests'
    'ProjectDefinitionTests'
    'ClassDescriptionTests'
    'SnapshotRestartTests'
    'MakefileTests'
    'TSTreeTests'
    'TSMultiTreeTests'
    "/ 'VMCrashTests'
    'ProcessTest'
    'PipeStreamTest'
    'JITTest'
    )

    "Modified: / 18-11-2014 / 11:54:47 / Jan Vrany <jan.vrany@fit.cvut.cz>"
!

testSuite

    | suite |

    suite := TestSuite named: self package.
    self testCaseNamesWithoutNamespace do:[:className |
	|fullName|

	fullName := ('RegressionTests::',className).
	('Loading ',className,'...') infoPrintCR.
	Smalltalk fileInClass:fullName package:self package.
	(Smalltalk classNamed:fullName) isNil ifTrue:[
	    ('**** Ouch - missing class: "',fullName,'"') infoPrintCR.
	] ifFalse:[
	    suite addTest:(Smalltalk classNamed:fullName) suite.
	].
    ].

    ^suite

    "Created: / 03-08-2011 / 09:19:50 / Jan Vrany <jan.vrany@fit.cvut.cz>"
! !

!stx_goodies_regression class methodsFor:'description'!

excludedFromPreRequisites
    "list all packages which should be ignored in the automatic
     preRequisites scan. See #preRequisites for more."

    ^ #(
	#'exept:libcrypt'    "loaded lazily by CryptTests - SHA256Stream - referenced by RegressionTests::CryptTests>>test06_sha256 "
	#'stx:goodies'    "no project def - CharacterEncoderCodeGenerator - referenced by RegressionTests::CharacterTests>>test01CaseTesting "
    )

    "Modified: / 03-03-2014 / 12:00:16 / Jan Vrany <jan.vrany@fit.cvut.cz>"
!

mandatoryPreRequisites
    "list packages which are mandatory as a prerequisite.
     This are packages containing superclasses of my classes and classes which
     are extended by myself.
     They are mandatory, because we need these packages as a prerequisite for loading and compiling.
     This method is generated automatically,
     by searching along the inheritance chain of all of my classes.
     Please take a look at the #referencedPreRequisites method as well."

    ^ #(
        #'stx:goodies/sunit'    "TestAsserter - superclass of RegressionTests::AssociationTests"
        #'stx:libbasic'    "ArrayedCollection - superclass of RegressionTests::CompilerTests2ExternalBytes"
        #'stx:libview'    "DisplaySurface - superclass of RegressionTests::WrongMethodCalledTest::GraphicTestView"
        #'stx:libview2'    "ApplicationModel - superclass of RegressionTests::LabelResizingTest"
    )
!

referencedPreRequisites
    "list packages which are a prerequisite, because they contain
     classes which are referenced by my classes.
     These packages are NOT needed as a prerequisite for compiling or loading,
     however, a class from it may be referenced during execution and having it
     unloaded then may lead to a runtime doesNotUnderstand error, unless the caller
     includes explicit checks for the package being present.
     This method is generated automatically,
     by searching all classes (and their packages) which are referenced by my classes.
     Please also take a look at the #mandatoryPreRequisites method"

    ^ #(
        #'stx:goodies/xml/stx'    "XMLStandardCoder - referenced by RegressionTests::XMLCoderTests>>encodeAndDecode:"
        #'stx:goodies/xml/vw'    "XML::Attribute - referenced by RegressionTests::MemoryTest>>test1"
        #'stx:libbasic2'    "ActorStream - referenced by RegressionTests::OperatingSystemTest>>helperActorStreamWithCommand:"
        #'stx:libbasic3'    "AbstractSourceCodeManager - referenced by RegressionTests::ChangeSetTests>>test_ClassSourceWriter_01"
        #'stx:libboss'    "BinaryIOManager - referenced by RegressionTests::BinaryIOTests>>testBehavior"
        #'stx:libcomp'    "InstrumentationContext - referenced by RegressionTests::CoverageInstrumentationTest>>test_01_instrumentation"
        #'stx:libhtml'    "HTMLDocumentView - referenced by RegressionTests::TestDialogs1>>openDocumentation"
        #'stx:libjavascript'    "JavaScriptCompiler - referenced by RegressionTests::JavaScriptTests>>execute:for:arguments:"
        #'stx:libtool'    "DebugView - referenced by RegressionTests::DebuggerTest>>testBlockVars_01"
        #'stx:libwidg'    "Button - referenced by RegressionTests::UTF8TestClass>>someJapaneseButton"
        #'stx:libwidg2'    "HierarchicalItem - referenced by RegressionTests::BinaryIOTests>>testSaveReadBOS"
    )
!

subProjects
    "list packages which are known as subprojects.
     The generated makefile will enter those and make there as well.
     However: they are not forced to be loaded when a package is loaded;
     for those, redefine requiredPrerequisites"

    ^ #(
    )
! !

!stx_goodies_regression class methodsFor:'description - contents'!

additionalRules_bc_dot_mak
    ^ '
clean::
        @del *.log
'

    "Created: / 25-09-2018 / 12:45:22 / Claus Gittinger"
!

additionalRules_make_dot_proto
    ^ '
clean::
        @rm -f *.log
'

    "Created: / 25-09-2018 / 12:44:59 / Claus Gittinger"
!

classNamesAndAttributes
    "lists the classes which are to be included in the project.
     Each entry in the list may be: a single class-name (symbol),
     or an array-literal consisting of class name and attributes.
     Attributes are: #autoload or #<os> where os is one of win32, unix,..."

    ^ #(
        "<className> or (<className> attributes...) in load order"
        #'stx_goodies_regression'
        #'RegressionTests::AssociationTests'
        #'RegressionTests::BayesClassifierTest'
        #'RegressionTests::BecomeTests'
        #'RegressionTests::BinaryIOTests'
        #'RegressionTests::BinaryTreeTester'
        #'RegressionTests::BlockTest'
        #'RegressionTests::BreakpointTests'
        #'RegressionTests::CECollectionExtensionTest'
        #'RegressionTests::CESequenceableCollectionExtensionTest'
        #'RegressionTests::CEStringExtensionTest'
        #'RegressionTests::CachedValueTest'
        #'RegressionTests::CharacterEncoderTests'
        #'RegressionTests::CharacterSetTests'
        #'RegressionTests::CharacterTests'
        #'RegressionTests::ClassAndMethodCompilingTestCase'
        #'RegressionTests::ClassDescriptionTests'
        #'RegressionTests::ClassWithoutVersionMethod'
        #'RegressionTests::CollectionTests'
        #'RegressionTests::CompilerTest'
        #'RegressionTests::CompilerTests2'
        #'RegressionTests::CompilerTests2ExternalBytes'
        #'RegressionTests::ComplexTest'
        #'RegressionTests::CompressionStreamTest'
        #'RegressionTests::CoverageInstrumentationTest'
        #'RegressionTests::CryptTests'
        #'RegressionTests::DebuggerTest'
        #'RegressionTests::DeepCopyTests'
        #'RegressionTests::DelayTest'
        #'RegressionTests::DictionaryTest'
        #'RegressionTests::DirectoryStreamTest'
        #'RegressionTests::DoubleMetaphoneStringComparatorTest'
        #'RegressionTests::EncoderTests'
        #'RegressionTests::EnumerationTests'
        #'RegressionTests::ExceptionTest'
        #'RegressionTests::ExternalStreamTest'
        #'RegressionTests::FileOpenTest'
        #'RegressionTests::FileStreamTest'
        #'RegressionTests::FilenameTests'
        #'RegressionTests::FloatTest'
        #'RegressionTests::FractionTest'
        #'RegressionTests::FuzzyMatcherTests'
        #'RegressionTests::GCTest'
        #'RegressionTests::GraphicDrawingTest'
        #'RegressionTests::HTMLParserTests'
        #'RegressionTests::HTTPServerTests'
        #'RegressionTests::Helper'
        #'RegressionTests::ImageReaderTest'
        #'RegressionTests::ImageTests'
        #'RegressionTests::IntegerTest'
        #'RegressionTests::JITTest'
        #'RegressionTests::JavaScriptTests'
        #'RegressionTests::KoelnerPhoneticCodeStringComparatorTest'
        #'RegressionTests::LabelResizingTest'
        #'RegressionTests::LinkedListTest'
        #'RegressionTests::LiteralsInMethodTests'
        #'RegressionTests::LoggedStreamTests'
        #'RegressionTests::MRAStringComparatorTest'
        #'RegressionTests::MakefileTests'
        #'RegressionTests::ManyProcessesTest'
        #'RegressionTests::MeasurementValueTests'
        #'RegressionTests::MemoryTest'
        #'RegressionTests::MetaNumbersTest'
        #'RegressionTests::Metaphone3StringComparatorTest'
        #'RegressionTests::MetaphoneStringComparatorTest'
        #'RegressionTests::MiracodeStringComparatorTest'
        #'RegressionTests::MySQLSoundexStringComparatorTest'
        #'RegressionTests::NumberTest'
        #'RegressionTests::OS_OLE_Tests'
        #'RegressionTests::OperatingSystemTest'
        #'RegressionTests::OperationInQueueTests'
        #'RegressionTests::PTYTest'
        #'RegressionTests::ParserTests'
        #'RegressionTests::PhonemStringComparatorTest'
        #'RegressionTests::PipeStreamTest'
        #'RegressionTests::PowerSetTests'
        #'RegressionTests::ProcessTest'
        #'RegressionTests::ProjectDefinitionTests'
        #'RegressionTests::QDoubleTests'
        #'RegressionTests::QueueTest'
        #'RegressionTests::QuickTestRunner'
        #'RegressionTests::RxTests'
        #'RegressionTests::STCCompilerTests'
        #'RegressionTests::ScaledDecimalTest'
        #'RegressionTests::SegmentedOrderedCollectionTests'
        #'RegressionTests::SemaphoreTest'
        #'RegressionTests::ServerSocketTest'
        #'RegressionTests::SharedQueueTest'
        #'RegressionTests::SmallIntegerTest'
        #'RegressionTests::SnapshotRestartTests'
        #'RegressionTests::SocketTests'
        #'RegressionTests::SortTests'
        #'RegressionTests::SoundexStringComparatorTest'
        #'RegressionTests::StackFrameTest'
        #'RegressionTests::StreamTests'
        #'RegressionTests::StreamUpToTests'
        #'RegressionTests::StringTests'
        #'RegressionTests::SunitXMLOutputTest'
        #'RegressionTests::TSTreeTests'
        #'RegressionTests::TestDialogs1'
        #'RegressionTests::TimeAndDateTest'
        #'RegressionTests::TimeDurationTest'
        #'RegressionTests::TypedArrayTests'
        #'RegressionTests::URLTest'
        #'RegressionTests::UTF8TestClass'
        #'RegressionTests::UninterpretedBytesTest'
        #'RegressionTests::VMCrashTestCase'
        #'RegressionTests::WeakCollectionTest'
        #'RegressionTests::Win32OLETests'
        #'RegressionTests::Win32OperatingSystemTest'
        #'RegressionTests::WritingToTranscriptOrStdoutTest'
        #'RegressionTests::WrongMethodCalledTest'
        #'RegressionTests::XMLCoderTests'
        #'RegressionTests::XPathTests'
        #'RegressionTests::ZipArchiveTests'
        #'RegressionTests::ChangeSetTests'
        #'RegressionTests::ClassBuilderTests'
        #'RegressionTests::TSMultiTreeTests'
        #'RegressionTests::VMCrashTests'
        (#'RegressionTests::LargeFloatTest' autoload)
        (#'RegressionTests::SelectorNamespacesTests' autoload)
        (#'RegressionTests::ExternalInterfaceTests' autoload)
        (#'RegressionTests::ContextTest2' autoload)
        (#'RegressionTests::BehaviorLookupObjectTests' autoload)
        (#'RegressionTests::CacheDictionaryTest' autoload)
    )

    "Modified: / 24-09-2018 / 21:13:43 / Claus Gittinger"
!

extensionMethodNames
    "lists the extension methods which are to be included in the project.
     Entries are 2-element array literals, consisting of class-name and selector.
     A correponding method with real names must be present in my concrete subclasses
     if it has extensions."

    ^ #(
    )
! !

!stx_goodies_regression class methodsFor:'description - project information'!

applicationIconFileName
    "Return the name (without suffix) of an icon-file (the app's icon); will be included in the rc-resource file"

    ^ nil
    "/ ^ self applicationName
!

companyName
    "Return a companyname which will appear in <lib>.rc"

    ^ 'eXept Software AG'
!

description
    "Return a description string which will appear in vc.def / bc.def"

    ^ 'Smalltalk/X regression tests'

    "Modified: / 18-12-2018 / 12:28:24 / Claus Gittinger"
!

legalCopyright
    "Return a copyright string which will appear in <lib>.rc"

    ^ 'Copyright eXept Software AG 1998-2016'
!

productName
    "Return a product name which will appear in <lib>.rc"

    ^ 'eXept addOns'
! !

!stx_goodies_regression class methodsFor:'documentation'!

version
    ^ '$Header$'
!

version_CVS
    ^ '$Header$'
! !

